1.What is it about?
It's about a download program.It can help you to install images easily.
2.How to use it?
If you are using Xiaoimage-1.1.3 and better,You can use "load-image someURL" to install images on this URL.
3.How to install it?
Using "pip install Xiaoimage" can install it.